#ifndef _CHRONOPTICS_TOF_TUI_CAMERA_H_
#define _CHRONOPTICS_TOF_TUI_CAMERA_H_

#include <chronoptics/tof/camera.h>
#include <chronoptics/tof/camera_config.h>

#ifdef __cplusplus
extern "C" {
#endif

/** The main interface to the tui camera
 */
typedef struct tof_tui_camera* tof_tui_camera_t;

typedef struct tof_tui_camera const* tof_tui_camera_ct;

/** Destruct tof_tui_camera */
TOF_EXPORT void tof_tui_camera_delete(tof_tui_camera_t ptr);

/** Construct the tui camera
 * @param ptr Pointer to class
 * @param serial The serial number of the camera to connect to, if the camera is
 * available over both usb and gige it will be connected over usb. If an empty
 * string is supplied the camera will connect to the first usb camera, if no usb
 * camera is connected it will connect to the first gige camera that replies
 * (this reply time is random, so you might connect to a different camera each
 * time if you've got multiple cameras connected to your network).
 * @param error Pointer to error
 * @return New object
 */
TOF_EXPORT tof_tui_camera_t tof_tui_camera_new(const char* serial, tof_error_t *error);

/** Set GPIO mode for a certain pin
 * @param ptr Pointer to class
 * @param pin Pin
 * @param gpio_mode GPIO Mode
 * @param error Pointer to error
 */
TOF_EXPORT void tof_tui_camera_set_gpio_mode(tof_tui_camera_t ptr, size_t pin, enum tof_gpio_mode gpio_mode, tof_error_t *error);

/** Set trigger mode
 * @param ptr Pointer to class
 * @param trigger_mode Trigger mode
 * @param error Pointer to error
 */
TOF_EXPORT void tof_tui_camera_set_trigger_mode(tof_tui_camera_t ptr, enum tof_trigger_mode trigger_mode, tof_error_t *error);

/** Construct a tui camera using the gige interface. This could be useful in two
 * cases. The first is when the camera is connected with both usb and ethernet
 * but you want to use ethernet. The second is when for some reason the default
 * maximum packet size is too large.
 * @param serial The serial number of the camera to connect to. If an empty
 * string is supplied the camera will connect to the first gige camera that
 * replies (this reply time is random, so you might connect to a different
 * camera each time if you've got multiple cameras connected to your network).
 * @param packet_size The packet size to use for communication over ethernet
 * @param error Pointer to error
 * @return A tui camera
 */
TOF_EXPORT tof_tui_camera_t tof_create_tui_camera_gige(const char* serial, uint16_t packet_size, tof_error_t *error);

#ifdef __cplusplus
}
#endif

#endif
