function ret_val = createTuiCameraGige(serial, varargin)
  % createTuiCameraGige
  %   Construct a tui camera using the gige interface. This could be useful in
  %   two cases. The first is when the camera is connected with both usb and
  %   ethernet but you want to use ethernet. The second is when for some reason
  %   the default maximum packet size is too large.
  %
  % Inputs:
  %   serial - string - The serial number of the camera to connect to. If an
  %                     empty string is supplied the camera will connect to the
  %                     first gige camera that replies (this reply time is
  %                     random, so you might connect to a different camera each
  %                     time if you've got multiple cameras connected to your
  %                     network).
  %   packet_size = 1472 - numeric - The packet size to use for communication
  %                                  over ethernet
  %
  % Output:
  %   ret_val - TuiCamera - A tui camera
  %

  packet_size = 1472;
  if size(varargin, 2) == 1
    packet_size = varargin{1};
  end

  ret_val = tof.mex('tof_create_tui_camera_gige', serial, packet_size);
  ret_val = tof.TuiCamera(ret_val);
end

