import cv2
import numpy as np
import chronoptics.tof as tof

cam = tof.KeaCamera("202001b")

cam.setOutputFrameTypes([tof.FrameType.XYZ, tof.FrameType.BGR])
cam.start()

# Wait for camera to warm up
for _ in range(60):
    frames = cam.getFrames()
    del frames

frames = cam.getFrames()
xyz = np.asarray(frames[0])
bgr = np.asarray(frames[1])

cam.stop()

calibration = cam.getCalibration()

cam_matrix = np.array(calibration.getRgbCameraMatrix())
cam_matrix.shape = (3, 3)
print(cam_matrix)

dist_coefficients = np.array(calibration.getRgbDistortionCoefficients())
print(dist_coefficients)

rvec = np.array(calibration.getRotationVector())
print(rvec)

tvec = np.array(calibration.getTranslationVector())
print(tvec)

row = 100
col = 120

point = xyz[row, col, 0:3]
if point[2] == 0.0:
    raise RuntimeError("Can't project point with zero value")

print(point)

image_point, _ = cv2.projectPoints(point, rvec, tvec, cam_matrix, dist_coefficients)
image_point = np.round(image_point[0][0])
print(image_point)

bgr_point = bgr[int(image_point[0]), int(image_point[1]), 0:3]
print(bgr_point)
